@@ -4,69 +4,6 @@ use feature ':5.10';
 use strict;
 use warnings;
 
-state $Indicators = __PACKAGE__->INDICATORS;
-state $ReBackbone = qr|^Content-Disposition:[ ]inline|m;
-state $StartingOf = { 'message' => ['This message was created automatically by Facebook.'] };
-state $ErrorCodes = {
-    # http://postmaster.facebook.com/response_codes
-    # NOT TESTD EXCEPT RCP-P2
-    'userunknown' => [
-        'RCP-P1',   # The attempted recipient address does not exist.
-        'INT-P1',   # The attempted recipient address does not exist.
-        'INT-P3',   # The attempted recpient group address does not exist.
-        'INT-P4',   # The attempted recipient address does not exist.
-    ],
-    'filtered' => [
-        'RCP-P2',   # The attempted recipient's preferences prevent messages from being delivered.
-        'RCP-P3',   # The attempted recipient's privacy settings blocked the delivery.
-    ],
-    'mesgtoobig' => [
-        'MSG-P1',   # The message exceeds Facebook's maximum allowed size.
-        'INT-P2',   # The message exceeds Facebook's maximum allowed size.
-    ],
-    'contenterror' => [
-        'MSG-P2',   # The message contains an attachment type that Facebook does not accept.
-        'MSG-P3',   # The message contains multiple instances of a header field that can only be present once. Please see RFC 5322, section 3.6 for more information
-        'POL-P6',   # The message contains a url that has been blocked by Facebook.
-        'POL-P7',   # The message does not comply with Facebook's abuse policies and will not be accepted.
-    ],
-    'securityerror' => [
-        'POL-P1',   # Your mail server's IP Address is listed on the Spamhaus PBL.
-        'POL-P2',   # Facebook will no longer accept mail from your mail server's IP Address.
-        'POL-P5',   # The message contains a virus.
-        'POL-P7',   # The message does not comply with Facebook's Domain Authentication requirements.
-    ],
-    'notaccept' => [
-        'POL-P3',   # Facebook is not accepting messages from your mail server. This will persist for 4 to 8 hours.
-        'POL-P4',   # Facebook is not accepting messages from your mail server. This will persist for 24 to 48 hours.
-        'POL-T1',   # Facebook is not accepting messages from your mail server, but they may be retried later. This will persist for 1 to 2 hours.
-        'POL-T2',   # Facebook is not accepting messages from your mail server, but they may be retried later. This will persist for 4 to 8 hours.
-        'POL-T3',   # Facebook is not accepting messages from your mail server, but they may be retried later. This will persist for 24 to 48 hours.
-    ],
-    'rejected' => [
-        'DNS-P1',   # Your SMTP MAIL FROM domain does not exist.
-        'DNS-P2',   # Your SMTP MAIL FROM domain does not have an MX record.
-        'DNS-T1',   # Your SMTP MAIL FROM domain exists but does not currently resolve.
-        'DNS-P3',   # Your mail server does not have a reverse DNS record.
-        'DNS-T2',   # You mail server's reverse DNS record does not currently resolve.
-    ],
-    'systemerror' => [
-        'CON-T1',   # Facebook's mail server currently has too many connections open to allow another one.
-    ],
-    'toomanyconn' => [
-        'CON-T3',   # Your mail server has opened too many new connections to Facebook's mail servers in a short period of time.
-    ],
-    'suspend' => [
-        'RCP-T4',   # The attempted recipient address is currently deactivated. The user may or may not reactivate it.
-    ],
-    'undefined' => [
-        'RCP-T1',   # The attempted recipient address is not currently available due to an internal system issue. This is a temporary condition.
-        'MSG-T1',   # The number of recipients on the message exceeds Facebook's allowed maximum.
-        'CON-T2',   # Your mail server currently has too many connections open to Facebook's mail servers.
-        'CON-T4',   # Your mail server has exceeded the maximum number of recipients for its current connection.
-    ],
-};
-
 sub description { 'Facebook: https://www.facebook.com' }
 sub make {
     # Detect an error from Facebook
@@ -82,12 +19,75 @@ sub make {
     return undef unless $mhead->{'from'} eq 'Facebook <mailer-daemon@mx.facebook.com>';
     return undef unless $mhead->{'subject'} eq 'Sorry, your message could not be delivered';
 
+    state $indicators = __PACKAGE__->INDICATORS;
+    state $rebackbone = qr|^Content-Disposition:[ ]inline|m;
+    state $startingof = { 'message' => ['This message was created automatically by Facebook.'] };
+    state $errorcodes = {
+        # http://postmaster.facebook.com/response_codes
+        # NOT TESTD EXCEPT RCP-P2
+        'userunknown' => [
+            'RCP-P1',   # The attempted recipient address does not exist.
+            'INT-P1',   # The attempted recipient address does not exist.
+            'INT-P3',   # The attempted recpient group address does not exist.
+            'INT-P4',   # The attempted recipient address does not exist.
+        ],
+        'filtered' => [
+            'RCP-P2',   # The attempted recipient's preferences prevent messages from being delivered.
+            'RCP-P3',   # The attempted recipient's privacy settings blocked the delivery.
+        ],
+        'mesgtoobig' => [
+            'MSG-P1',   # The message exceeds Facebook's maximum allowed size.
+            'INT-P2',   # The message exceeds Facebook's maximum allowed size.
+        ],
+        'contenterror' => [
+            'MSG-P2',   # The message contains an attachment type that Facebook does not accept.
+            'MSG-P3',   # The message contains multiple instances of a header field that can only be present once. Please see RFC 5322, section 3.6 for more information
+            'POL-P6',   # The message contains a url that has been blocked by Facebook.
+            'POL-P7',   # The message does not comply with Facebook's abuse policies and will not be accepted.
+        ],
+        'securityerror' => [
+            'POL-P1',   # Your mail server's IP Address is listed on the Spamhaus PBL.
+            'POL-P2',   # Facebook will no longer accept mail from your mail server's IP Address.
+            'POL-P5',   # The message contains a virus.
+            'POL-P7',   # The message does not comply with Facebook's Domain Authentication requirements.
+        ],
+        'notaccept' => [
+            'POL-P3',   # Facebook is not accepting messages from your mail server. This will persist for 4 to 8 hours.
+            'POL-P4',   # Facebook is not accepting messages from your mail server. This will persist for 24 to 48 hours.
+            'POL-T1',   # Facebook is not accepting messages from your mail server, but they may be retried later. This will persist for 1 to 2 hours.
+            'POL-T2',   # Facebook is not accepting messages from your mail server, but they may be retried later. This will persist for 4 to 8 hours.
+            'POL-T3',   # Facebook is not accepting messages from your mail server, but they may be retried later. This will persist for 24 to 48 hours.
+        ],
+        'rejected' => [
+            'DNS-P1',   # Your SMTP MAIL FROM domain does not exist.
+            'DNS-P2',   # Your SMTP MAIL FROM domain does not have an MX record.
+            'DNS-T1',   # Your SMTP MAIL FROM domain exists but does not currently resolve.
+            'DNS-P3',   # Your mail server does not have a reverse DNS record.
+            'DNS-T2',   # You mail server's reverse DNS record does not currently resolve.
+        ],
+        'systemerror' => [
+            'CON-T1',   # Facebook's mail server currently has too many connections open to allow another one.
+        ],
+        'toomanyconn' => [
+            'CON-T3',   # Your mail server has opened too many new connections to Facebook's mail servers in a short period of time.
+        ],
+        'suspend' => [
+            'RCP-T4',   # The attempted recipient address is currently deactivated. The user may or may not reactivate it.
+        ],
+        'undefined' => [
+            'RCP-T1',   # The attempted recipient address is not currently available due to an internal system issue. This is a temporary condition.
+            'MSG-T1',   # The number of recipients on the message exceeds Facebook's allowed maximum.
+            'CON-T2',   # Your mail server currently has too many connections open to Facebook's mail servers.
+            'CON-T4',   # Your mail server has exceeded the maximum number of recipients for its current connection.
+        ],
+    };
+
     require Sisimai::RFC1894;
     my $fieldtable = Sisimai::RFC1894->FIELDTABLE;
     my $permessage = {};    # (Hash) Store values of each Per-Message field
 
     my $dscontents = [__PACKAGE__->DELIVERYSTATUS];
-    my $emailsteak = Sisimai::RFC5322->fillet($mbody, $ReBackbone);
+    my $emailsteak = Sisimai::RFC5322->fillet($mbody, $rebackbone);
     my $readcursor = 0;     # (Integer) Points the current cursor position
     my $recipients = 0;     # (Integer) The number of 'Final-Recipient' header
     my $fbresponse = '';    # (String) Response code from Facebook
@@ -99,10 +99,10 @@ sub make {
         # to the previous line of the beginning of the original message.
         unless( $readcursor ) {
             # Beginning of the bounce message or message/delivery-status part
-            $readcursor |= $Indicators->{'deliverystatus'} if index($e, $StartingOf->{'message'}->[0]) == 0;
+            $readcursor |= $indicators->{'deliverystatus'} if index($e, $startingof->{'message'}->[0]) == 0;
             next;
         }
-        next unless $readcursor & $Indicators->{'deliverystatus'};
+        next unless $readcursor & $indicators->{'deliverystatus'};
         next unless length $e;
 
         if( my $f = Sisimai::RFC1894->match($e) ) {
@@ -161,9 +161,9 @@ sub make {
             $fbresponse = sprintf("%s-%s%d", $1, $2, $3);
         }
 
-        SESSION: for my $r ( keys %$ErrorCodes ) {
+        SESSION: for my $r ( keys %$errorcodes ) {
             # Verify each regular expression of session errors
-            PATTERN: for my $rr ( @{ $ErrorCodes->{ $r } } ) {
+            PATTERN: for my $rr ( @{ $errorcodes->{ $r } } ) {
                 # Check each regular expression
                 next(PATTERN) unless $fbresponse eq $rr;
                 $e->{'reason'} = $r;
