@@ -5,52 +5,6 @@ use strict;
 use warnings;
 
 # Based on Sisimai::Lhost::Exim
-state $Indicators = __PACKAGE__->INDICATORS;
-state $ReBackbone = qr|^Included is a copy of the message header:|m;
-state $StartingOf = { 'message' => ['This message was created automatically by mail delivery software.'] };
-state $ReCommands = [
-    qr/SMTP error from remote (?:mail server|mailer) after ([A-Za-z]{4})/,
-    qr/SMTP error from remote (?:mail server|mailer) after end of ([A-Za-z]{4})/,
-];
-state $MessagesOf = {
-    'userunknown' => ['user not found'],
-    'hostunknown' => [
-        'all host address lookups failed permanently',
-        'all relevant MX records point to non-existent hosts',
-        'Unrouteable address',
-    ],
-    'mailboxfull' => [
-        'mailbox is full',
-        'error: quota exceed',
-    ],
-    'notaccept' => [
-        'an MX or SRV record indicated no SMTP service',
-        'no host found for existing SMTP connection',
-    ],
-    'syntaxerror' => [
-        'angle-brackets nested too deep',
-        'expected word or "<"',
-        'domain missing in source-routed address',
-        'malformed address:',
-    ],
-    'systemerror' => [
-        'delivery to file forbidden',
-        'delivery to pipe forbidden',
-        'local delivery failed',
-        'LMTP error after ',
-    ],
-    'contenterror' => ['Too many "Received" headers'],
-};
-state $DelayedFor = [
-    'retry timeout exceeded',
-    'No action is required on your part',
-    'retry time not reached for any host after a long failure period',
-    'all hosts have been failing for a long time and were last tried',
-    'Delay reason: ',
-    'has been frozen',
-    'was frozen on arrival by ',
-];
-
 sub description { 'McAfee SaaS' }
 sub make {
     # Detect an error from MXLogic
@@ -79,8 +33,54 @@ sub make {
     }x;
     return undef unless $match;
 
+    state $indicators = __PACKAGE__->INDICATORS;
+    state $rebackbone = qr|^Included is a copy of the message header:|m;
+    state $startingof = { 'message' => ['This message was created automatically by mail delivery software.'] };
+    state $recommands = [
+        qr/SMTP error from remote (?:mail server|mailer) after ([A-Za-z]{4})/,
+        qr/SMTP error from remote (?:mail server|mailer) after end of ([A-Za-z]{4})/,
+    ];
+    state $messagesof = {
+        'userunknown' => ['user not found'],
+        'hostunknown' => [
+            'all host address lookups failed permanently',
+            'all relevant MX records point to non-existent hosts',
+            'Unrouteable address',
+        ],
+        'mailboxfull' => [
+            'mailbox is full',
+            'error: quota exceed',
+        ],
+        'notaccept' => [
+            'an MX or SRV record indicated no SMTP service',
+            'no host found for existing SMTP connection',
+        ],
+        'syntaxerror' => [
+            'angle-brackets nested too deep',
+            'expected word or "<"',
+            'domain missing in source-routed address',
+            'malformed address:',
+        ],
+        'systemerror' => [
+            'delivery to file forbidden',
+            'delivery to pipe forbidden',
+            'local delivery failed',
+            'LMTP error after ',
+        ],
+        'contenterror' => ['Too many "Received" headers'],
+    };
+    state $delayedfor = [
+        'retry timeout exceeded',
+        'No action is required on your part',
+        'retry time not reached for any host after a long failure period',
+        'all hosts have been failing for a long time and were last tried',
+        'Delay reason: ',
+        'has been frozen',
+        'was frozen on arrival by ',
+    ];
+
     my $dscontents = [__PACKAGE__->DELIVERYSTATUS];
-    my $emailsteak = Sisimai::RFC5322->fillet($mbody, $ReBackbone);
+    my $emailsteak = Sisimai::RFC5322->fillet($mbody, $rebackbone);
     my $readcursor = 0;     # (Integer) Points the current cursor position
     my $recipients = 0;     # (Integer) The number of 'Final-Recipient' header
     my $localhost0 = '';    # (String) Local MTA
@@ -91,10 +91,10 @@ sub make {
         # to the previous line of the beginning of the original message.
         unless( $readcursor ) {
             # Beginning of the bounce message or message/delivery-status part
-            $readcursor |= $Indicators->{'deliverystatus'} if index($e, $StartingOf->{'message'}->[0]) == 0;
+            $readcursor |= $indicators->{'deliverystatus'} if index($e, $startingof->{'message'}->[0]) == 0;
             next;
         }
-        next unless $readcursor & $Indicators->{'deliverystatus'};
+        next unless $readcursor & $indicators->{'deliverystatus'};
         next unless length $e;
 
         # This message was created automatically by mail delivery software.
@@ -156,7 +156,7 @@ sub make {
 
         unless( $e->{'command'} ) {
             # Get the SMTP command name for the session
-            SMTP: for my $r ( @$ReCommands ) {
+            SMTP: for my $r ( @$recommands ) {
                 # Verify each regular expression of SMTP commands
                 next unless $e->{'diagnosis'} =~ $r;
                 $e->{'command'} = uc $1;
@@ -174,16 +174,16 @@ sub make {
 
             } else {
                 # Verify each regular expression of session errors
-                SESSION: for my $r ( keys %$MessagesOf ) {
+                SESSION: for my $r ( keys %$messagesof ) {
                     # Check each regular expression
-                    next unless grep { index($e->{'diagnosis'}, $_) > -1 } @{ $MessagesOf->{ $r } };
+                    next unless grep { index($e->{'diagnosis'}, $_) > -1 } @{ $messagesof->{ $r } };
                     $e->{'reason'} = $r;
                     last;
                 }
 
                 unless( $e->{'reason'} ) {
                     # The reason "expired"
-                    $e->{'reason'} = 'expired' if grep { index($e->{'diagnosis'}, $_) > -1 } @$DelayedFor;
+                    $e->{'reason'} = 'expired' if grep { index($e->{'diagnosis'}, $_) > -1 } @$delayedfor;
                 }
             }
         }
