@@ -3,15 +3,6 @@ use feature ':5.10';
 use strict;
 use warnings;
 
-state $PreMatches = [qw|NoRelaying Blocked MailboxFull HasMoved Rejected|];
-state $ModulePath = {
-    'Sisimai::Reason::NoRelaying'  => 'Sisimai/Reason/NoRelaying.pm',
-    'Sisimai::Reason::Blocked'     => 'Sisimai/Reason/Blocked.pm',
-    'Sisimai::Reason::MailboxFull' => 'Sisimai/Reason/MailboxFull.pm',
-    'Sisimai::Reason::HasMoved'    => 'Sisimai/Reason/HasMoved.pm',
-    'Sisimai::Reason::Rejected'    => 'Sisimai/Reason/Rejected.pm',
-};
-
 sub text  { 'userunknown' }
 sub description { "Email rejected due to a local part of a recipient's email address does not exist" }
 sub match {
@@ -165,8 +156,17 @@ sub true {
         #   Status: 5.1.1
         #   Diagnostic-Code: SMTP; 550 5.1.1 <***@example.jp>:
         #     Recipient address rejected: User unknown in local recipient table
+        state $prematches = [qw|NoRelaying Blocked MailboxFull HasMoved Rejected|];
+        state $ModulePath = {
+            'Sisimai::Reason::NoRelaying'  => 'Sisimai/Reason/NoRelaying.pm',
+            'Sisimai::Reason::Blocked'     => 'Sisimai/Reason/Blocked.pm',
+            'Sisimai::Reason::MailboxFull' => 'Sisimai/Reason/MailboxFull.pm',
+            'Sisimai::Reason::HasMoved'    => 'Sisimai/Reason/HasMoved.pm',
+            'Sisimai::Reason::Rejected'    => 'Sisimai/Reason/Rejected.pm',
+        };
         my $matchother = 0;
-        for my $e ( @$PreMatches ) {
+
+        for my $e ( @$prematches ) {
             # Check the value of "Diagnostic-Code" with other error patterns.
             my $p = 'Sisimai::Reason::'.$e;
             require $ModulePath->{ $p };
